@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2012-2021 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2012-2022 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -190,27 +190,27 @@ as_metadata_xml_parse_components_node (AsMetadata *metad, AsContext *context, xm
 	gchar *tmp;
 
 	/* set origin of this metadata */
-	tmp = (gchar*) xmlGetProp (node, (xmlChar*) "origin");
+	tmp = as_xml_get_prop_value (node, "origin");
 	as_context_set_origin (context, tmp);
 	as_metadata_set_origin (metad, tmp);
 	g_free (tmp);
 
 	/* set baseurl for the media files */
 	if (!as_flags_contains (priv->parse_flags, AS_PARSE_FLAG_IGNORE_MEDIABASEURL)) {
-		tmp = (gchar*) xmlGetProp (node, (xmlChar*) "media_baseurl");
+		tmp = as_xml_get_prop_value (node, "media_baseurl");
 		as_context_set_media_baseurl (context, tmp);
 		as_metadata_set_media_baseurl (metad, tmp);
 		g_free (tmp);
 	}
 
 	/* set architecture for the components */
-	tmp = (gchar*) xmlGetProp (node, (xmlChar*) "architecture");
+	tmp = as_xml_get_prop_value (node, "architecture");
 	as_context_set_architecture (context, tmp);
 	as_metadata_set_architecture (metad, tmp);
 	g_free (tmp);
 
 	/* collection metadata allows setting a priority for components */
-	priority_str = (gchar*) xmlGetProp (node, (xmlChar*) "priority");
+	priority_str = as_xml_get_prop_value (node, "priority");
 	if (priority_str != NULL) {
 		gint default_priority;
 		default_priority = g_ascii_strtoll (priority_str, NULL, 10);
@@ -605,6 +605,8 @@ as_metadata_parse_desktop_data (AsMetadata *metad, const gchar *data, const gcha
 					   NULL, /* l10n function */
 					   NULL, /* l10n func user data */
 					   &tmp_error);
+	if (ret)
+		ret = !as_is_empty (cid);
 	if (!ret) {
 		if (tmp_error == NULL) {
 			if (cid == NULL)
@@ -639,6 +641,9 @@ as_metadata_parse_desktop_data (AsMetadata *metad, const gchar *data, const gcha
  *
  * Parses an AppStream upstream metadata file.
  *
+ * If @file does not exist, %G_IO_ERROR_NOT_FOUND will be returned. Other
+ * #GIOErrors and #AsMetadataErrors may be returned as appropriate.
+ *
  * Returns: %TRUE if the file was parsed without error.
  **/
 gboolean
