@@ -102,7 +102,7 @@ as_releases_to_metainfo_xml_chunk (GPtrArray *releases, GError **error)
 	as_context_set_style (ctx, AS_FORMAT_STYLE_METAINFO);
 
 	root = xmlNewNode (NULL, (xmlChar*) "component");
-	n_releases = xmlNewChild (root, NULL, (xmlChar*) "releases", NULL);
+	n_releases = as_xml_add_node (root, "releases");
 
 	for (guint i = 0; i < releases->len; ++i) {
 		AsRelease *release = AS_RELEASE (g_ptr_array_index (releases, i));
@@ -411,7 +411,7 @@ as_news_releases_to_yaml (GPtrArray *releases, gchar **yaml_data)
 							if (iter2->type != XML_ELEMENT_NODE)
 								continue;
 							if (g_strcmp0 ((gchar*) iter2->name, "li") == 0) {
-								g_autofree gchar *content = (gchar*) xmlNodeGetContent (iter2);
+								g_autofree gchar *content = as_xml_get_node_value_raw (iter2);
 								as_yaml_emit_scalar (&emitter, as_strstripnl (content));
 							}
 						}
