@@ -106,6 +106,11 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("The mentioned tag is empty, which is highly likely not intended as it should have content.")
 	},
 
+	{ "tag-invalid-text-content",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  N_("The mentioned tag has text content, even though it must not contain text.")
+	},
+
 	{ "cid-is-not-rdns",
 	  AS_ISSUE_SEVERITY_ERROR,
 	  N_("The component ID is required to follow a reverse domain-name scheme for its name. See the AppStream specification for details.")
@@ -199,6 +204,48 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("The update-contact does not appear to be a valid email address (escaping of `@` is only allowed as `_at_` or `_AT_`).")
 	},
 
+	{ "screenshot-invalid-width",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  /* TRANSLATORS: Please do not translate AppStream tag/property names (in backticks). */
+	  N_("The `width` property must be a positive integer.")
+	},
+
+	{ "screenshot-invalid-height",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  /* TRANSLATORS: Please do not translate AppStream tag/property names (in backticks). */
+	  N_("The `height` property must be a positive integer.")
+	},
+
+	{ "screenshot-image-invalid-type",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  /* TRANSLATORS: Please do not translate AppStream tag/property names (in backticks). */
+	  N_("The image type must be either `source` or `thumbnail`.")
+	},
+
+	{ "screenshot-image-missing-width",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  /* TRANSLATORS: Please do not translate AppStream tag/property names (in backticks). */
+	  N_("The `width` property must be present if the image type is `thumbnail`.")
+	},
+
+	{ "screenshot-image-missing-height",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  /* TRANSLATORS: Please do not translate AppStream tag/property names (in backticks). */
+	  N_("The `height` property must be present if the image type is `thumbnail`.")
+	},
+
+	{ "screenshot-image-source-duplicated",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  /* TRANSLATORS: Please do not translate AppStream tag/property names (in backticks). */
+	  N_("There can only be one `source` image per screenshot and language.")
+	},
+
+	{ "screenshot-image-source-missing",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  /* TRANSLATORS: Please do not translate AppStream tag/property names (in backticks). */
+	  N_("A screenshot must have at least one image of type `source`.")
+	},
+
 	{ "screenshot-image-not-found",
 	  AS_ISSUE_SEVERITY_WARNING,
 	  N_("Unable to reach the screenshot image on its remote location - does the image exist?")
@@ -268,6 +315,11 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("The default screenshot of a software component must not be a video. Use a static image as default screenshot and set the video as a secondary screenshot.")
 	},
 
+	{ "screenshot-default-missing",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  N_("No screenshot is marked as default.")
+	},
+
 	{ "relation-invalid-tag",
 	  AS_ISSUE_SEVERITY_WARNING,
 	  N_("Found an unknown tag in a requires/recommends group. This is likely an error, because a component relation of this type is unknown.")
@@ -359,6 +411,12 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("The set tag value is not valid for an `internet` relation.")
 	},
 
+	{ "relation-internet-bandwidth-offline",
+	  AS_ISSUE_SEVERITY_WARNING,
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("The `bandwidth_mbitps` property is not allowed when using `offline-only` as value.")
+	},
+
 	{ "relation-internet-bandwidth-value-invalid",
 	  AS_ISSUE_SEVERITY_WARNING,
 	  N_("The value of this property must be a positive integer value, describing the minimum required bandwidth in mbit/s.")
@@ -878,20 +936,20 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 
 	{ "content-rating-missing",
 	  AS_ISSUE_SEVERITY_INFO,
-	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks) and keep the URL intact. */
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
 	  N_("This component has no `content_rating` tag to provide age rating information. "
 	     "You can generate the tag data online by answering a few questions at https://hughsie.github.io/oars/"),
 	},
 
 	{ "component-tag-missing-namespace",
 	  AS_ISSUE_SEVERITY_ERROR,
-	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks) and keep the URL intact. */
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
 	  N_("This `tag` is missing a `namespace` attribute."),
 	},
 
 	{ "component-tag-invalid",
 	  AS_ISSUE_SEVERITY_ERROR,
-	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks) and keep the URL intact. */
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
 	  N_("This tag or its namespace contains invalid characters. Only lower-cased ASCII letters, numbers, dots, hyphens and underscores are permitted."),
 	},
 
@@ -910,9 +968,32 @@ AsValidatorIssueTag as_validator_issue_tag_list[] =  {
 	  N_("This color is not a valid HTML color code."),
 	},
 
+	{ "custom-invalid-tag",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("The `custom` tag can only contain `value` children."),
+	},
+
+	{ "custom-key-missing",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("This `custom` tag value is missing a `key` attribute."),
+	},
+
+	{ "custom-key-duplicated",
+	  AS_ISSUE_SEVERITY_ERROR,
+	  N_("A key can only be used once."),
+	},
+
+	{ "custom-value-empty",
+	  AS_ISSUE_SEVERITY_INFO,
+	  N_("This custom value is empty."),
+	},
+
 	{ "metainfo-localized-keywords-tag",
 	  AS_ISSUE_SEVERITY_ERROR,
-	  N_("A <keywords/> tag must not be localized in metainfo files (upstream metadata). "
+	  /* TRANSLATORS: Please do not translate AppStream tag and property names (in backticks). */
+	  N_("A `keywords` tag must not be localized in metainfo files (upstream metadata). "
 	     "Localize the individual keyword entries instead.")
 	},
 
